/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.support.avtransport;

import java.util.logging.Logger;
import org.teleal.cling.controlpoint.ActionCallback;
import org.teleal.cling.model.action.ActionException;
import org.teleal.cling.model.action.ActionInvocation;
import org.teleal.cling.model.meta.DeviceService;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;
import org.teleal.cling.model.message.UpnpResponse;

/**
 *
 * @author Christian Bauer
 */
public abstract class SetAVTransportURIActionCallback extends ActionCallback {

    private static Logger log = Logger.getLogger(SetAVTransportURIActionCallback.class.getName());

    public SetAVTransportURIActionCallback(DeviceService service, String uri) {
        super(new ActionInvocation(service.getService().getAction("SetAVTransportURI")));

        log.fine("Creating SetAVTransportURI action for URI: " + uri);

        try {
            getActionInvocation().getInput().addValue(new UnsignedIntegerFourBytes(0));
            getActionInvocation().getInput().addValue(uri);
            getActionInvocation().getInput().addValue(null);
        } catch (ActionException ex) {
            throw new RuntimeException(ex);
        }
    }

    public void failure(ActionInvocation actionInvocation, UpnpResponse operation) {
        failure(createDefaultFailureMessage(actionInvocation, operation));
    }

    public abstract void failure(String failureMessage);

}