/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.support.renderingcontrol.callback;

import java.util.logging.Logger;
import org.teleal.cling.controlpoint.ActionCallback;
import org.teleal.cling.model.action.ActionException;
import org.teleal.cling.model.action.ActionInvocation;
import org.teleal.cling.model.meta.DeviceService;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;
import org.teleal.cling.model.types.UnsignedIntegerTwoBytes;
import org.teleal.cling.support.renderingcontrol.Channel;

/**
 *
 * @author Christian Bauer
 */
public abstract class SetVolumeActionCallback extends ActionCallback {

    private static Logger log = Logger.getLogger(SetVolumeActionCallback.class.getName());

    public SetVolumeActionCallback(DeviceService service, long newVolume) {
        super(new ActionInvocation(service.getService().getAction("SetVolume")));

        try {
            getActionInvocation().getInput().addValue(new UnsignedIntegerFourBytes(0));
            getActionInvocation().getInput().addValue(Channel.Master);
            getActionInvocation().getInput().addValue(new UnsignedIntegerTwoBytes(newVolume));
        } catch (ActionException ex) {
            throw new RuntimeException(ex);
        }
    }

    public void failure(ActionInvocation actionInvocation, UpnpResponse operation) {
        failure(createDefaultFailureMessage(actionInvocation, operation));
    }

    public abstract void failure(String failureMessage);

}